/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'th', {
	bold: 'ตัวหนา',
	italic: 'ตัวเอียง',
	strike: 'ตัวขีดเส้นทับ',
	subscript: 'ตัวห้อย',
	superscript: 'ตัวยก',
	underline: 'ตัวขีดเส้นใต้'
} );
