/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colordialog', 'zh-cn', {
	clear: '清除',
	highlight: '高亮',
	options: '颜色选项',
	selected: '选择颜色',
	title: '选择颜色'
} );
