/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'ka', {
	confirmCleanup: 'ჩასასმელი ტექსტი ვორდიდან გადმოტანილს გავს - გინდათ მისი წინასწარ გაწმენდა?',
	error: 'შიდა შეცდომის გამო ვერ მოხერხდა ტექსტის გაწმენდა',
	title: 'ვორდიდან ჩასმა',
	toolbar: 'ვორდიდან ჩასმა'
} );
