/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colordialog', 'hi', {
	clear: 'Clear', // MISSING
	highlight: 'Highlight', // MISSING
	options: 'Color Options', // MISSING
	selected: 'Selected Color', // MISSING
	title: 'Select color' // MISSING
} );
