/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'en-ca', {
	bold: 'Bold',
	italic: 'Italic',
	strike: 'Strike Through',
	subscript: 'Subscript',
	superscript: 'Superscript',
	underline: 'Underline'
} );
